# Examples

This section contains a few examples demonstrating what you can do with mqttwarn,
and about how mqttwarn can be used with more advanced configurations.

:::{toctree}
:maxdepth: 1
alexa/readme.md
arduino-temperature/readme.md
frigate/README.rst
mediaplayer/readme.md
owntracks-ntfy/readme.md
warntoggle/README.rst
zabbix-iot/readme.md
:::
